function [Img, header, Nframes, SDD, res] = LoadEpid(FILENAME)

% () First version
% 23/04/09 V0.01 
% Modified to set IAS2 SIDCorrection to 1.5 and IAS3 to 0.0 once has
% recognised which is.  If old EPID images that don't have RTImageSID label set in header gets 
% this from EpidSettings file.
% Currently doesn't handle very old images that don't have information in
% header.
% 27.04.09 modified to accept Research EPID images with no pixel dimensions
% 04.05.09 fixed to accept Epid off-arm ang give correct resolution
% 18.05.09 changed to accept PSM or other dicoms with no header info
% need to resave PSMs with header info using dicomwrite('copy') function

header=dicominfo(FILENAME);
DI=dicomread(header);

%Epid_Settings;

% CU
% if strcmp(header.RTImageSID, '')  % Old images - didn't have SDD in header - get from EpidSettings
%     SDD = DefSDD;
%     SIDcorrection = 1.5;
%     res = PixelAtDetector.*(100/SDD+SIDcorrection);
% else

% PSMs etc don't currently have these defined - will crash.

OffArm = strcmp(header.ImagePlanePixelSpacing,'');
%
temp = strfind(header.RTImageDescription,'Avg''s');
if isempty(temp)
    % IAS3 Tit-Zeus-Hunt
    % Number of Frames
    temp = strfind(header.RTImageDescription,'Frames');
    Nframes=sscanf(header.RTImageDescription(temp+6:end),'%f');
    % Pixel Values
    if strcmp(header.RTImageLabel(1:3),'MFF')  % if a FF acquisition
        Img=double(DI);
    else
        Img=(32768/2)-double(DI);
    end
    % Source - Detector Distance Plane of Detector
    % Pixel size at isocentre

    if OffArm % is Research EPID off-arm
        SIDcorrection=1.5; % assume set to top surface?
        SDD = DefSDD;   % from EpidSettings file
        res = PixelAtDetector*100/(DefSDD+SIDcorrection);
    else
        SIDcorrection = 0; % IAS3 currently set this way.
        SDD = header.RTImageSID/10; % work with cm
        res = mean((header.ImagePlanePixelSpacing/10))*100/((header.RTImageSID/10)+SIDcorrection);
    end
else
    % IAS2 Phx-Law
    % Number of Frames
    Nframes=sscanf(header.RTImageDescription(temp+5 : end),'%f');
    % Pixel Values
    if strcmp(header.RTImageLabel(1:3),'MFF')  % if a FF acquisition
        Img=double(DI)-32768;   % if a FF acquisition
    else
        Img=32768-double(DI);
    end
    % Source - Detector Distance Plane of Detector
    % Pixel size at isocentre
    if OffArm % is Research EPID off-arm
        SIDcorrection=1.5; % assume set to top surface?
        SDD = DefSDD;
        res = PixelAtDetector*100/(DefSDD+SIDcorrection);
    else
        SIDcorrection = 1.5; % Phx and Law set this way
        SDD = header.RTImageSID/10; % work with cm
        res = mean((header.ImagePlanePixelSpacing/10))*100/((header.RTImageSID/10)+SIDcorrection);
    end
end

